GoogleChromePolicyVersionsV1AdditionalTargetKeyName

Struct GoogleChromePolicyVersionsV1AdditionalTargetKeyName 

pub struct GoogleChromePolicyVersionsV1AdditionalTargetKeyName {
    pub key: Option<String>,
    pub key_description: Option<String>,
}
Additional key names that will be used to identify the target of the policy value.

This type is not used in any activity, and only used as part of another schema.

Fields

key: Option<String>

Key name.

key_description: Option<String>

Key description.