pub struct GoogleChromePolicyVersionsV1ModifyOrgUnitPolicyRequest {
pub policy_target_key: Option<GoogleChromePolicyVersionsV1PolicyTargetKey>,
pub policy_value: Option<GoogleChromePolicyVersionsV1PolicyValue>,
pub update_mask: Option<FieldMask>,
}Expand description
Request parameters for modifying a policy value for a specific org unit target.
This type is not used in any activity, and only used as part of another schema.
Fields
policy_target_key: Option<GoogleChromePolicyVersionsV1PolicyTargetKey>Required. The key of the target for which we want to modify a policy. The target resource must point to an Org Unit.
policy_value: Option<GoogleChromePolicyVersionsV1PolicyValue>The new value for the policy.
update_mask: Option<FieldMask>Required. Policy fields to update. Only fields in this mask will be updated; other fields in policy_value will be ignored (even if they have values). If a field is in this list it must have a value in ‘policy_value’.