GoogleChromePolicyVersionsV1PolicyTargetKey

Struct GoogleChromePolicyVersionsV1PolicyTargetKey 

pub struct GoogleChromePolicyVersionsV1PolicyTargetKey {
    pub additional_target_keys: Option<HashMap<String, String>>,
    pub target_resource: Option<String>,
}
The key used to identify the target on which the policy will be applied.

This type is not used in any activity, and only used as part of another schema.

Fields

additional_target_keys: Option<HashMap<String, String>>

Map containing the additional target key name and value pairs used to further identify the target of the policy.

target_resource: Option<String>

The target resource on which this policy is applied. The following resources are supported: * Organizational Unit (“orgunits/{orgunit_id}”) * Group (“groups/{group_id}”)