pub struct MediaMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on media resources.
It is not used directly, but through the ChromePolicy hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_chromepolicy1 as chromepolicy1;
use chromepolicy1::{ChromePolicy, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = ChromePolicy::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `upload(...)`
// to build up your call.
let rb = hub.media();Implementations
Sourceimpl<'a, C> MediaMethods<'a, C>
impl<'a, C> MediaMethods<'a, C>
Sourcepub fn upload(
&self,
request: GoogleChromePolicyVersionsV1UploadPolicyFileRequest,
customer: &str,
) -> MediaUploadCall<'a, C>
pub fn upload( &self, request: GoogleChromePolicyVersionsV1UploadPolicyFileRequest, customer: &str, ) -> MediaUploadCall<'a, C>
Create a builder to help you perform the following task:
Creates an enterprise file from the content provided by user. Returns a public download url for end user.
Arguments
request- No description provided.customer- Required. The customer for which the file upload will apply.