Proto2FieldDescriptorProto

Struct Proto2FieldDescriptorProto 

pub struct Proto2FieldDescriptorProto {
    pub default_value: Option<String>,
    pub json_name: Option<String>,
    pub label: Option<String>,
    pub name: Option<String>,
    pub number: Option<i32>,
    pub oneof_index: Option<i32>,
    pub proto3_optional: Option<bool>,
    pub type_: Option<String>,
    pub type_name: Option<String>,
}
Describes a field within a message.

This type is not used in any activity, and only used as part of another schema.

Fields

default_value: Option<String>

For numeric types, contains the original text representation of the value. For booleans, “true” or “false”. For strings, contains the default text contents (not escaped in any way). For bytes, contains the C escaped value. All bytes >= 128 are escaped.

json_name: Option<String>

JSON name of this field. The value is set by protocol compiler. If the user has set a “json_name” option on this field, that option’s value will be used. Otherwise, it’s deduced from the field’s name by converting it to camelCase.

label: Option<String>

no description provided

name: Option<String>

no description provided

number: Option<i32>

no description provided

oneof_index: Option<i32>

If set, gives the index of a oneof in the containing type’s oneof_decl list. This field is a member of that oneof.

proto3_optional: Option<bool>

If true, this is a proto3 “optional”. When a proto3 field is optional, it tracks presence regardless of field type. When proto3_optional is true, this field must belong to a oneof to signal to old proto3 clients that presence is tracked for this field. This oneof is known as a “synthetic” oneof, and this field must be its sole member (each proto3 optional field gets its own synthetic oneof). Synthetic oneofs exist in the descriptor only, and do not generate any API. Synthetic oneofs must be ordered after all “real” oneofs. For message fields, proto3_optional doesn’t create any semantic change, since non-repeated message fields always track presence. However it still indicates the semantic detail of whether the user wrote “optional” or not. This can be useful for round-tripping the .proto file. For consistency we give message fields a synthetic oneof also, even though it is not required to track presence. This is especially important because the parser can’t tell if a field is a message or an enum, so it must always create a synthetic oneof. Proto2 optional fields do not set this flag, because they already indicate optional with LABEL_OPTIONAL.

type_: Option<String>

If type_name is set, this need not be set. If both this and type_name are set, this must be one of TYPE_ENUM, TYPE_MESSAGE or TYPE_GROUP.

type_name: Option<String>

For message and enum types, this is the name of the type. If the name starts with a ‘.’, it is fully-qualified. Otherwise, C++-like scoping rules are used to find the type (i.e. first the nested types within this message are searched, then within the parent, on up to the root namespace).