pub struct CustomerMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on customer resources.
It is not used directly, but through the ChromePolicy hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_chromepolicy1 as chromepolicy1;
use chromepolicy1::{ChromePolicy, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = ChromePolicy::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `policies_groups_batch_delete(...)`, `policies_groups_batch_modify(...)`, `policies_groups_list_group_priority_ordering(...)`, `policies_groups_update_group_priority_ordering(...)`, `policies_networks_define_certificate(...)`, `policies_networks_define_network(...)`, `policies_networks_remove_certificate(...)`, `policies_networks_remove_network(...)`, `policies_orgunits_batch_inherit(...)`, `policies_orgunits_batch_modify(...)`, `policies_resolve(...)`, `policy_schemas_get(...)` and `policy_schemas_list(...)`
// to build up your call.
let rb = hub.customers();Implementations
Sourceimpl<'a, C> CustomerMethods<'a, C>
impl<'a, C> CustomerMethods<'a, C>
Sourcepub fn policies_groups_batch_delete(
&self,
request: GoogleChromePolicyVersionsV1BatchDeleteGroupPoliciesRequest,
customer: &str,
) -> CustomerPolicyGroupBatchDeleteCall<'a, C>
pub fn policies_groups_batch_delete( &self, request: GoogleChromePolicyVersionsV1BatchDeleteGroupPoliciesRequest, customer: &str, ) -> CustomerPolicyGroupBatchDeleteCall<'a, C>
Create a builder to help you perform the following task:
Delete multiple policy values that are applied to a specific group. All targets must have the same target format. That is to say that they must point to the same target resource and must have the same keys specified in additionalTargetKeyNames, though the values for those keys may be different. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- ID of the Google Workspace account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_groups_batch_modify(
&self,
request: GoogleChromePolicyVersionsV1BatchModifyGroupPoliciesRequest,
customer: &str,
) -> CustomerPolicyGroupBatchModifyCall<'a, C>
pub fn policies_groups_batch_modify( &self, request: GoogleChromePolicyVersionsV1BatchModifyGroupPoliciesRequest, customer: &str, ) -> CustomerPolicyGroupBatchModifyCall<'a, C>
Create a builder to help you perform the following task:
Modify multiple policy values that are applied to a specific group. All targets must have the same target format. That is to say that they must point to the same target resource and must have the same keys specified in additionalTargetKeyNames, though the values for those keys may be different. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- ID of the Google Workspace account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_groups_list_group_priority_ordering(
&self,
request: GoogleChromePolicyVersionsV1ListGroupPriorityOrderingRequest,
customer: &str,
) -> CustomerPolicyGroupListGroupPriorityOrderingCall<'a, C>
pub fn policies_groups_list_group_priority_ordering( &self, request: GoogleChromePolicyVersionsV1ListGroupPriorityOrderingRequest, customer: &str, ) -> CustomerPolicyGroupListGroupPriorityOrderingCall<'a, C>
Create a builder to help you perform the following task:
Retrieve a group priority ordering for an app. The target app must be supplied in additionalTargetKeyNames in the PolicyTargetKey. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- Required. ID of the Google Workspace account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_groups_update_group_priority_ordering(
&self,
request: GoogleChromePolicyVersionsV1UpdateGroupPriorityOrderingRequest,
customer: &str,
) -> CustomerPolicyGroupUpdateGroupPriorityOrderingCall<'a, C>
pub fn policies_groups_update_group_priority_ordering( &self, request: GoogleChromePolicyVersionsV1UpdateGroupPriorityOrderingRequest, customer: &str, ) -> CustomerPolicyGroupUpdateGroupPriorityOrderingCall<'a, C>
Create a builder to help you perform the following task:
Update a group priority ordering for an app. The target app must be supplied in additionalTargetKeyNames in the PolicyTargetKey. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- Required. ID of the Google Workspace account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_networks_define_certificate(
&self,
request: GoogleChromePolicyVersionsV1DefineCertificateRequest,
customer: &str,
) -> CustomerPolicyNetworkDefineCertificateCall<'a, C>
pub fn policies_networks_define_certificate( &self, request: GoogleChromePolicyVersionsV1DefineCertificateRequest, customer: &str, ) -> CustomerPolicyNetworkDefineCertificateCall<'a, C>
Create a builder to help you perform the following task:
Creates a certificate at a specified OU for a customer.
Arguments
request- No description provided.customer- Required. The customer for which the certificate will apply.
Sourcepub fn policies_networks_define_network(
&self,
request: GoogleChromePolicyVersionsV1DefineNetworkRequest,
customer: &str,
) -> CustomerPolicyNetworkDefineNetworkCall<'a, C>
pub fn policies_networks_define_network( &self, request: GoogleChromePolicyVersionsV1DefineNetworkRequest, customer: &str, ) -> CustomerPolicyNetworkDefineNetworkCall<'a, C>
Create a builder to help you perform the following task:
Define a new network.
Arguments
request- No description provided.customer- Required. The customer who will own this new network.
Sourcepub fn policies_networks_remove_certificate(
&self,
request: GoogleChromePolicyVersionsV1RemoveCertificateRequest,
customer: &str,
) -> CustomerPolicyNetworkRemoveCertificateCall<'a, C>
pub fn policies_networks_remove_certificate( &self, request: GoogleChromePolicyVersionsV1RemoveCertificateRequest, customer: &str, ) -> CustomerPolicyNetworkRemoveCertificateCall<'a, C>
Create a builder to help you perform the following task:
Remove an existing certificate by guid.
Arguments
request- No description provided.customer- Required. The customer whose certificate will be removed.
Sourcepub fn policies_networks_remove_network(
&self,
request: GoogleChromePolicyVersionsV1RemoveNetworkRequest,
customer: &str,
) -> CustomerPolicyNetworkRemoveNetworkCall<'a, C>
pub fn policies_networks_remove_network( &self, request: GoogleChromePolicyVersionsV1RemoveNetworkRequest, customer: &str, ) -> CustomerPolicyNetworkRemoveNetworkCall<'a, C>
Create a builder to help you perform the following task:
Remove an existing network by guid.
Arguments
request- No description provided.customer- Required. The customer whose network will be removed.
Sourcepub fn policies_orgunits_batch_inherit(
&self,
request: GoogleChromePolicyVersionsV1BatchInheritOrgUnitPoliciesRequest,
customer: &str,
) -> CustomerPolicyOrgunitBatchInheritCall<'a, C>
pub fn policies_orgunits_batch_inherit( &self, request: GoogleChromePolicyVersionsV1BatchInheritOrgUnitPoliciesRequest, customer: &str, ) -> CustomerPolicyOrgunitBatchInheritCall<'a, C>
Create a builder to help you perform the following task:
Modify multiple policy values that are applied to a specific org unit so that they now inherit the value from a parent (if applicable). All targets must have the same target format. That is to say that they must point to the same target resource and must have the same keys specified in additionalTargetKeyNames, though the values for those keys may be different. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- ID of the G Suite account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_orgunits_batch_modify(
&self,
request: GoogleChromePolicyVersionsV1BatchModifyOrgUnitPoliciesRequest,
customer: &str,
) -> CustomerPolicyOrgunitBatchModifyCall<'a, C>
pub fn policies_orgunits_batch_modify( &self, request: GoogleChromePolicyVersionsV1BatchModifyOrgUnitPoliciesRequest, customer: &str, ) -> CustomerPolicyOrgunitBatchModifyCall<'a, C>
Create a builder to help you perform the following task:
Modify multiple policy values that are applied to a specific org unit. All targets must have the same target format. That is to say that they must point to the same target resource and must have the same keys specified in additionalTargetKeyNames, though the values for those keys may be different. On failure the request will return the error details as part of the google.rpc.Status.
Arguments
request- No description provided.customer- ID of the G Suite account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policies_resolve(
&self,
request: GoogleChromePolicyVersionsV1ResolveRequest,
customer: &str,
) -> CustomerPolicyResolveCall<'a, C>
pub fn policies_resolve( &self, request: GoogleChromePolicyVersionsV1ResolveRequest, customer: &str, ) -> CustomerPolicyResolveCall<'a, C>
Create a builder to help you perform the following task:
Gets the resolved policy values for a list of policies that match a search query.
Arguments
request- No description provided.customer- ID of the G Suite account or literal “my_customer” for the customer associated to the request.
Sourcepub fn policy_schemas_get(
&self,
name: &str,
) -> CustomerPolicySchemaGetCall<'a, C>
pub fn policy_schemas_get( &self, name: &str, ) -> CustomerPolicySchemaGetCall<'a, C>
Create a builder to help you perform the following task:
Get a specific policy schema for a customer by its resource name.
Arguments
name- Required. The policy schema resource name to query.
Sourcepub fn policy_schemas_list(
&self,
parent: &str,
) -> CustomerPolicySchemaListCall<'a, C>
pub fn policy_schemas_list( &self, parent: &str, ) -> CustomerPolicySchemaListCall<'a, C>
Create a builder to help you perform the following task:
Gets a list of policy schemas that match a specified filter value for a given customer.
Arguments
parent- Required. The customer for which the listing request will apply.