pub struct Proto2FileDescriptorProto {
pub edition_deprecated: Option<String>,
pub enum_type: Option<Vec<Proto2EnumDescriptorProto>>,
pub message_type: Option<Vec<Proto2DescriptorProto>>,
pub name: Option<String>,
pub option_dependency: Option<Vec<String>>,
pub package: Option<String>,
pub syntax: Option<String>,
}Expand description
Describes a complete .proto file.
This type is not used in any activity, and only used as part of another schema.
Fields
edition_deprecated: Option<String>copybara:strip_begin TODO(b/297898292) Deprecate and remove this field in favor of enums. copybara:strip_end
enum_type: Option<Vec<Proto2EnumDescriptorProto>>no description provided
message_type: Option<Vec<Proto2DescriptorProto>>All top-level definitions in this file.
name: Option<String>file name, relative to root of source tree
option_dependency: Option<Vec<String>>Names of files imported by this file purely for the purpose of providing option extensions. These are excluded from the dependency list above.
package: Option<String>e.g. “foo”, “foo.bar”, etc.
syntax: Option<String>The syntax of the proto file. The supported values are “proto2”, “proto3”, and “editions”. If edition is present, this value must be “editions”. WARNING: This field should only be used by protobuf plugins or special cases like the proto compiler. Other uses are discouraged and developers should rely on the protoreflect APIs for their client language.